fnss.topologies.parsers.parse_topology_zoo — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.topologies.parsers.parse_topology_zoo

`parse_topology_zoo`(path)

  Parse a topology from the Topology Zoo dataset.

  Note: the parsing of multigraphs is currently not supported. If the topology to be parsed contains bundled links, i.e. multiple links between the same pair or nodes, the parsing may fail or parse only one link of a bundle. Even if the parsing is successful, the use of some algorithms for topology configuration may fail or have unexpected results.

  Parameters : | path : str The path to the Topology Zoo file
  Returns : | topology : Topology or DirectedTopology

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »